@@ -19,3 +19,7 @@ HUE_BRIDGE_IP_ADDRESS = get_env("HUE_BRIDGE_IP_ADDRESS")
 HUE_BRIDGE_USERNAME = get_env("HUE_BRIDGE_USERNAME")
 HUE_TEST_DEFAULT_INTERVAL = get_env("HUE_TEST_DEFAULT_INTERVAL", 0.01)
 HUE_MAX_SATURATION = get_env("HUE_MAX_SATURATION", 254)
+
+RAG_DEFAULT_DOCUMENTS_OBJECT_NAME = get_env("RAG_DEFAULT_DOCUMENTS_OBJECT_NAME")
+
+HUGGINGFACEHUB_API_TOKEN = get_env("HUGGINGFACEHUB_API_TOKEN")
