@@ -21,6 +21,11 @@ parser.add_argument(
     type=str,
     help=" | ".join(list_of_script_names),
 )
+parser.add_argument(
+    "--script_version",
+    type=str,
+    default="base",
+)
 parser.add_argument(
     "--object_name",
     type=str,
@@ -48,6 +53,13 @@ parser.add_argument(
     default=1,
     help="0 | 1",
 )
+parser.add_argument(
+    "--runnable",
+    type=str,
+    default="",
+    help="~node_1,~node_2",
+)
+
 args = parser.parse_args()
 
 delim = " " if args.delim == "space" else args.delim
@@ -64,13 +76,16 @@ if args.task == "list":
 elif args.task == "run":
     success, script = load_script(
         script_name=args.script_name,
+        script_version=args.script_version,
         object_name=args.object_name,
         test_mode=args.test_mode == 1,
         verbose=args.verbose == 1,
     )
 
     if success:
-        success = script.run()
+        success = script.run(
+            runnable=args.runnable,
+        )
 else:
     success = None
 
