@@ -1,14 +1,15 @@
 from typing import List, Type
 
-from blue_assistant.script.repository.generic.classes import GenericScript
+from blue_assistant.script.repository.base.root import RootScript
+from blue_assistant.script.repository.base.classes import BaseScript
 from blue_assistant.script.repository.blue_amo.classes import BlueAmoScript
 from blue_assistant.script.repository.hue.classes import HueScript
 from blue_assistant.script.repository.orbital_data_explorer.classes import (
     OrbitalDataExplorerScript,
 )
 
-list_of_script_classes: List[Type[GenericScript]] = [
-    GenericScript,
+list_of_script_classes: List[Type[RootScript]] = [
+    BaseScript,
     BlueAmoScript,
     HueScript,
     OrbitalDataExplorerScript,
