@@ -1,4 +1,15 @@
 import re
+from urllib.parse import urlparse, urlunparse
+
+
+# https://chatgpt.com/c/67d733a0-4be4-8005-bf52-fb9ba32487c2
+def normalize_url(url: str) -> str:
+    return urlunparse(
+        urlparse(url)._replace(
+            query="",
+            fragment="",
+        ),
+    )
 
 
 def url_to_filename(
